@@ -374,7 +374,7 @@ class FieldBase(metaclass=ABCMeta):
     @property
     def is_complex(self) -> bool:
         """bool: whether the field contains real or complex data"""
-        return np.iscomplexobj(self.data)  # type: ignore
+        return np.iscomplexobj(self.data)
 
     @property
     def attributes(self) -> Dict[str, Any]:
@@ -712,8 +712,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             label (str, optional):
                 Name of the field
             dtype (numpy dtype):
-                The data type of the field. All the numpy dtypes are supported. If
-                omitted, it will be determined from `data` automatically.
+                The data type of the field. If omitted, it will be determined from
+                `data` automatically.
             with_ghost_cells (bool):
                 Indicates whether the ghost cells are included in data
         """
@@ -826,7 +826,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             data = real_part + 1j * imag_part
         else:
             # create real random numbers for the field
-            data = rng.uniform(vmin, vmax, size=shape)  # type: ignore
+            data = rng.uniform(vmin, vmax, size=shape)
 
         return cls(grid, data=data, label=label, dtype=dtype)
 
@@ -1242,7 +1242,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             if self.rank == 0:
                 fill = self.data.dtype.type(fill)
             else:
-                fill = np.broadcast_to(fill, self.data_shape).astype(self.data.dtype)
+                fill = np.broadcast_to(fill, self.data_shape).astype(self.data.dtype)  # type: ignore
 
         # use the full array and assume BCs are set via ghost points
         interpolate_single = grid._make_interpolator_compiled(fill=fill, **kwargs)
@@ -1471,7 +1471,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 non-uniform discretizations.
         """
         point = np.atleast_1d(point)
-        amount = np.broadcast_to(amount, self.data_shape)
+        amount = np.broadcast_to(amount, self.data_shape)  # type: ignore
         grid = self.grid
         grid_dim = len(grid.axes)
 
@@ -1544,18 +1544,23 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         return (self._data_full[i_wall] + self._data_full[i_ghost]) / 2  # type: ignore
 
     @fill_in_docstring
-    def set_ghost_cells(self, bc: BoundariesData, *, args=None) -> None:
+    def set_ghost_cells(
+        self, bc: BoundariesData, *, normal: bool = False, args=None
+    ) -> None:
         """set the boundary values on virtual points for all boundaries
 
         Args:
             bc (str or list or tuple or dict):
                 The boundary conditions applied to the field.
                 {ARG_BOUNDARIES}
+            normal (bool):
+                Flag indicating whether the condition is only applied in the normal
+                direction.
             args:
                 Additional arguments that might be supported by special boundary
                 conditions.
         """
-        bcs = self.grid.get_boundary_conditions(bc, rank=self.rank)
+        bcs = self.grid.get_boundary_conditions(bc, rank=self.rank, normal=normal)
         bcs.set_ghost_cells(self._data_full, args=args)
 
     @property
@@ -1636,7 +1641,9 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             label (str, optional):
                 Name of the returned field
             **kwargs:
-                Additional arguments affecting how the operator behaves.
+                Additional arguments affecting how the operator behaves. For instance,
+                the argument `normal_bcs` can be used to control whether boundary
+                conditions only specify normal components or not.
 
         Returns:
             Field with new data. This is stored at `out` if given.
