@@ -374,7 +374,7 @@ class GridBase(metaclass=ABCMeta):
     def cell_volumes(self) -> np.ndarray:
         """:class:`~numpy.ndarray`: volume of each cell"""
         vols = functools.reduce(np.outer, self.cell_volume_data)
-        return np.broadcast_to(vols, self.shape)  # type: ignore
+        return np.broadcast_to(vols, self.shape)
 
     @cached_property()
     def uniform_cell_volumes(self) -> bool:
@@ -454,7 +454,7 @@ class GridBase(metaclass=ABCMeta):
         # assemble into array
         shape_bndry = tuple(self.shape[i] for i in range(self.num_axes) if i != axis)
         shape = shape_bndry + (self.num_axes,)
-        return np.stack(points, -1).reshape(shape)
+        return np.stack(points, -1).reshape(shape)  # type: ignore
 
     @property
     @abstractmethod
@@ -716,7 +716,10 @@ class GridBase(metaclass=ABCMeta):
 
     @abstractmethod
     def get_boundary_conditions(
-        self, bc: "BoundariesData" = "auto_periodic_neumann", rank: int = 0
+        self,
+        bc: "BoundariesData" = "auto_periodic_neumann",
+        rank: int = 0,
+        normal: bool = False,
     ) -> Boundaries:
         pass
 
@@ -880,6 +883,8 @@ class GridBase(metaclass=ABCMeta):
         self,
         operator: Union[str, OperatorInfo],
         bc: BoundariesData,
+        *,
+        normal_bcs: bool = None,
         **kwargs,
     ) -> Callable[..., np.ndarray]:
         """return a compiled function applying an operator with boundary conditions
@@ -901,6 +906,12 @@ class GridBase(metaclass=ABCMeta):
             bc (str or list or tuple or dict):
                 The boundary conditions applied to the field.
                 {ARG_BOUNDARIES}
+            normal_bcs (bool):
+                Flag indicating whether the condition is only applied in the normal
+                direction. This value normally determined automatically from the
+                properties of the operator. Here, normal=True is assumed if the operator
+                reduced the rank of the field, so that the output has lower rank than
+                the input.
             **kwargs:
                 Specifies extra arguments influencing how the operator is created.
 
@@ -913,8 +924,13 @@ class GridBase(metaclass=ABCMeta):
         # instantiate the operator
         operator = self._get_operator_info(operator)
         operator_raw = operator.factory(self, **kwargs)
+
         # set the boundary conditions before applying this operator
-        bcs = self.get_boundary_conditions(bc, rank=operator.rank_in)
+        if normal_bcs is None:
+            # determine whether it is sufficient to apply the boundary condition in the
+            # normal direction
+            normal_bcs = operator.rank_in > operator.rank_out
+        bcs = self.get_boundary_conditions(bc, rank=operator.rank_in, normal=normal_bcs)
 
         # calculate shapes of the full data
         shape_in_full = (self.dim,) * operator.rank_in + self._shape_full
@@ -1098,7 +1114,7 @@ class GridBase(metaclass=ABCMeta):
         """
         if all(np.isscalar(d) for d in self.cell_volume_data):
             # all cells have the same volume
-            cell_volume = np.product(self.cell_volume_data)
+            cell_volume = np.product(self.cell_volume_data)  # type: ignore
 
             @jit
             def get_cell_volume(*args) -> float:
@@ -1502,7 +1518,7 @@ class GridBase(metaclass=ABCMeta):
 
         if self.uniform_cell_volumes:
             # all cells have the same volume
-            cell_volume = np.product(self.cell_volume_data)
+            cell_volume = np.product(self.cell_volume_data)  # type: ignore
 
             @jit
             def integrate(arr: np.ndarray) -> Number:
