@@ -63,7 +63,9 @@ class Boundaries(list):
         return f"[{items}]"
 
     @classmethod
-    def from_data(cls, grid: GridBase, boundaries, rank: int = 0) -> Boundaries:
+    def from_data(
+        cls, grid: GridBase, boundaries, rank: int = 0, normal: bool = False
+    ) -> Boundaries:
         """
         Creates all boundaries from given data
 
@@ -81,6 +83,9 @@ class Boundaries(list):
                 * tuple pair specifying the low and high boundary individually
             rank (int):
                 The tensorial rank of the field for this boundary condition
+            normal (bool):
+                Flag indicating whether the condition is only applied in the normal
+                direction.
         """
         # check whether this is already the correct class
         if isinstance(boundaries, Boundaries):
@@ -128,7 +133,7 @@ class Boundaries(list):
         if isinstance(boundaries, (str, dict)):
             # one specification for all axes
             bcs = [
-                get_boundary_axis(grid, i, boundaries, rank=rank)
+                get_boundary_axis(grid, i, boundaries, rank=rank, normal=normal)
                 for i in range(grid.num_axes)
             ]
 
@@ -137,12 +142,12 @@ class Boundaries(list):
             if len(boundaries) == grid.num_axes:
                 # assume that data is given for each boundary
                 bcs = [
-                    get_boundary_axis(grid, i, boundary, rank=rank)
+                    get_boundary_axis(grid, i, boundary, rank=rank, normal=normal)
                     for i, boundary in enumerate(boundaries)
                 ]
             elif grid.num_axes == 1 and len(boundaries) == 2:
                 # special case where the two sides can be specified directly
-                bcs = [get_boundary_axis(grid, 0, boundaries, rank=rank)]
+                bcs = [get_boundary_axis(grid, 0, boundaries, rank=rank, normal=normal)]
 
         if bcs is None:
             # none of the logic worked
