@@ -121,7 +121,7 @@ def _heaviside_implemention(x1, x2=0.5):
 
 @overload(np.heaviside)
 def np_heaviside(x1, x2):
-    """numba implementation of the heaviside function"""
+    """numba implementation of the Heaviside function"""
     return _heaviside_implemention
 
 
@@ -439,7 +439,7 @@ class ExpressionBase(metaclass=ABCMeta):
         constants = tuple(self.consts)
 
         # turn the expression into a callable function
-        self._logger.info("Compile sympy expression `%s`", self._sympy_expr)
+        self._logger.info("Parse sympy expression `%s`", self._sympy_expr)
         func = sympy.lambdify(
             variables + constants,
             self._sympy_expr,
